Name:		kernel-module-hostap
Version:	0.1.3
Release:	0.fdr.3.2
Summary:	Driver for Intersil Prism2/2.5/3 802.11b wireless cards.

License:	GPL
URL:		http://hostap.epitest.fi/
Group:		System Environment/Kernel

Source:		http://hostap.epitest.fi/releases/hostap-driver-%{version}.tar.gz
Patch0:		hostap-makefile.patch
Patch1:		hostap-compat.patch
Patch2:		hostap-download.patch
Patch3:		hostap-autotools.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root

# what kernel are we building for ?
%{!?kernel: %define kernel %(uname -r)}
# get the correct kernel package release by stripping kernel modifiers
%define krel %(echo %{kernel} | sed -e s/smp//g -)
# get a type modifier for the kernel, (null) or -smp
%if %(echo %{kernel} | grep -c smp)
  %{expand:%%define ktype -smp}
%else
  %define ktype %{nil}
%endif

# what kernel "flavor" are we building for ?
%{expand:%%define post26 %(if echo %{kernel} | grep -c "^2\.[01234]" > /dev/null; then echo 0; else echo 1; fi)}

%if %{post26}
ExclusiveArch: i386 i586 i686
%else
ExclusiveArch: i686 athlon
%endif

# don't build debuginfo packages for kernel modules
%define debug_package %{nil}

# where the kernel build tree lives for post 2.6
%define basedeveldir %{_libdir}/kernel-module-devel-%{krel}
                                                                                
BuildRequires:	autoconf
BuildRequires:  automake

%if %{post26}
BuildRequires:	kernel-module-devel-%{krel}
%else
BuildRequires:  kernel-source = %{krel}
%endif

%description
This is a Linux driver for wireless LAN cards based on Intersil's
Prism2/2.5/3 chipset. The driver supports a so called Host AP mode, i.e.,
it takes care of IEEE 802.11 management functions in the host computer and
acts as an access point. This does not require any special firmware for the
wireless LAN card. In addition to this, it has support for normal station
operations in BSS and possible also in IBSS.

You can rebuild this RPM by using
--target target_arch
--define "kernel (uname -r value)"
                                                                                
--without download
  Build the driver without firmware download support.  The default is to
  build with download support.

%ifarch i386
# only create devel package for i386, and make it contain all possible devel
# files
%package devel-%{krel}
Summary:	Headers and symbol versions for hostap 
Group:		Development/System
Provides:	%{name} = %{version}-%{release}

%description devel-%{krel}
This is a Linux driver for wireless LAN cards based on Intersil's
Prism2/2.5/3 chipset. The driver supports a so called Host AP mode, i.e.,
it takes care of IEEE 802.11 management functions in the host computer and
acts as an access point. This does not require any special firmware for the
wireless LAN card. In addition to this, it has support for normal station
operations in BSS and possible also in IBSS.

This package contains headers and symbol versions for all archs and types
of kernel.
%else
%package %{kernel}
Summary:	Driver for Intersil Prism2/2.5/3 802.11b wireless cards
Group:		System Environment/Kernel
Provides:	%{name} = %{version}-%{release}, kernel-module
Requires(pre):	modutils
Requires:	/boot/vmlinuz-%{kernel}

%description %{kernel}
This is a Linux driver for wireless LAN cards based on Intersil's
Prism2/2.5/3 chipset. The driver supports a so called Host AP mode, i.e.,
it takes care of IEEE 802.11 management functions in the host computer and
acts as an access point. This does not require any special firmware for the
wireless LAN card. In addition to this, it has support for normal station
operations in BSS and possible also in IBSS.

%endif

%prep
%setup -q -n hostap-driver-%{version}
%patch0 -p0
%patch1 -p1
%{!?_without_download:%patch2 -p1}
%patch3 -p2

# for post 2.6:
# if arch i386, build four times to get all devel stuff
# if arch i586/i686, just build the module
%if %{post26}
%ifarch i386
%build
bash autogen.sh || true

%install
rm -rf "$RPM_BUILD_ROOT"

echo "Post 2.6 build, devel package"
# build and install four times to get all the development files
for type in "" "-smp"
do 
  for target in i586 i686
  do
    %define develdir %{basedeveldir}/kernel$type-%{krel}.$target.rpm
    %configure --with-linuxdir=%{develdir}

    make clean
    make
    %makeinstall \
	modulesdir=$RPM_BUILD_ROOT/lib/modules/%{kernel} \
	modulesdeveldir=$RPM_BUILD_ROOT%{develdir}
  done
done

# remove all the modules and config stuff since we only package devel files
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}
rm -rf $RPM_BUILD_ROOT/lib/modules

%else
%build
echo "Post 2.6 build, kernel%{ktype}-%{krel}.%{_target_cpu} package"
%define develdir %{basedeveldir}/kernel%{ktype}-%{krel}.%{_target_cpu}.rpm

bash autogen.sh --with-linuxdir=%{develdir}
%configure --with-linuxdir=%{develdir}
make

%install
rm -rf $RPM_BUILD_ROOT
%makeinstall \
	modulesdir=$RPM_BUILD_ROOT/lib/modules/%{kernel} \
	modulesdeveldir=$RPM_BUILD_ROOT%{develdir}
# remove the devel files since they're packaged in the i386 stage
rm -rf $RPM_BUILD_ROOT%{develdir}

%endif # i386

%else # not post26
%build
echo "Pre 2.6 build, kernel%{ktype}-%{krel}.%{_target_cpu} package"
bash autogen.sh \
  --with-rpm-target=%{_target_cpu} \
  --with-kernel-release=%{kernel} \
  --with-linuxdir=/usr/src/linux-%{krel}
%configure \
  --with-rpm-target=%{_target_cpu} \
  --with-kernel-release=%{kernel} \
  --with-linuxdir=/usr/src/linux-%{krel}

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
%define develdir /usr/src/linux-%{krel}
%makeinstall \
	modulesdir=$RPM_BUILD_ROOT/lib/modules/%{kernel} \
	modulesdeveldir=$RPM_BUILD_ROOT%{develdir}
%endif # post26

%clean
rm -rf $RPM_BUILD_ROOT

%ifnarch i386
%post %{kernel}
depmod -ae -F /boot/System.map-%{kernel} %{kernel} > /dev/null

%postun %{kernel}
depmod -ae -F /boot/System.map-%{kernel} %{kernel} > /dev/null
%endif

# for post26, we create an i386 devel-%{krel} package
%if %{post26}
%ifarch i386
%files devel-%{krel}
%defattr(-,root,root,-)
%{basedeveldir}/*/*.symvers
%dir %{basedeveldir}/*/include/modules/hostap
%{basedeveldir}/*/include/modules/hostap/hostap_crypt.h
%endif
%endif

%ifarch i586 i686 athlon
%files %{kernel}
%defattr(-,root,root,-)
%doc ChangeLog COPYING README
%verify(not mtime) %config /etc/pcmcia/hostap_cs.conf
/lib/modules/%{kernel}/kernel/drivers/net/wireless/hostap*.*o
# for pre 2.6, we include the .ver files in the kernel package directly
%if !%{post26}
/usr/src/linux-%{krel}/include/linux/modules/hostap.ver
/usr/src/linux-%{krel}/include/modules/hostap/hostap_crypt.h
%endif
%endif

%changelog
* Tue Jun 15 2004 Thomas Vander Stichele <thomas at apestaart dot org>
- 0.1.3-0.fdr.3: never fail on autogen

* Thu Jun 03 2004 Thomas Vander Stichele <thomas at apestaart dot org>
- 0.1.3-0.fdr.2: integrated both pre and post 2.6 builds

* Sat May 22 2004 Thomas Vander Stichele <thomas at apestaart dot org>
- 0.1.3-0.fdr.1: new upstream version

* Sat May 22 2004 Thomas Vander Stichele <thomas at apestaart dot org>
- 0.1.2-0.fdr.6: use our patch system that works with linux 2.6

* Sat Apr 17 2004 Thomas Vander Stichele <thomas at apestaart dot org>
- 0.1.2-0.fdr.5: package hostap.ver so packages can be rebuilt that need it

* Wed Jan 14 2004 Steven Pritchard <steve@kspei.com> 0.1.2-0.fdr.4
- Add "--without download" to the description

* Sat Dec 20 2003 Ville Skyttä <ville.skytta at iki.fi> - 0.1.2-0.fdr.3
- Really honor --target.
- New version of kmodhelper.

* Sat Dec 20 2003 Ville Skyttä <ville.skytta at iki.fi> - 0.1.2-0.fdr.2
- Major specfile simplifications, no more hardcoded kernel variants.
- Honor --target and kernel CC properly.
- Run depmod only if installing/uninstalling modules for the running kernel.

* Thu Nov 20 2003 Steven Pritchard <steve@kspei.com> 0.1.2-0.fdr.1
- Second Fedora release candidate
- Fixed to (hopefully) easily allow building for various kernels

* Wed Nov 19 2003 Steven Pritchard <steve@kspei.com> 0.1.2-0.fdr.0.1
- First Fedora release candidate

* Mon Nov 17 2003 Steven Pritchard <steve@kspei.com> 0.1.2
- Updated to 0.1.2

* Thu Oct 30 2003 Steven Pritchard <steve@kspei.com> 0.1.1
- Initial packaging
